spm <- read.csv("supermarkets.csv")

# assume empty values should be filled with 0
spm <- transform(spm,
                 other.rev = ifelse(is.na(other.rev), 0, other.rev))

# assume that negative amounts have only a sign error
spm <- transform(spm, other.rev = abs(other.rev))

# ratio estimator for staff conditional on turnover
Rhat <- with(spm,
             mean(staff, na.rm = TRUE)/mean(turnover, na.rm = TRUE))

# impute 'staff' variable where possible using the ratio estimator
spm <- transform(spm,
                 staff = ifelse(is.na(staff), Rhat * turnover, staff))

# add a column
spm <- transform(spm, ratio = turnover/total.rev)

# write output
write.csv(spm, "supermarkets_treated.csv", row.names = FALSE)
